@@ -8,6 +8,7 @@ import sys  # noqa: E402
 from .. import logs  # noqa: E402
 from ..argument_parser import Parser  # noqa: E402
 from ..utils import get_installation_info  # noqa: E402
+from ..shells import shell  # noqa: E402
 from .alias import print_alias  # noqa: E402
 from .fix_command import fix_command  # noqa: E402
 
@@ -20,7 +21,7 @@ def main():
         parser.print_help()
     elif known_args.version:
         logs.version(get_installation_info().version,
-                     sys.version.split()[0])
+                     sys.version.split()[0], shell.info())
     elif known_args.command or 'TF_HISTORY' in os.environ:
         fix_command(known_args)
     elif known_args.alias:
