@@ -1,13 +1,14 @@
 import re
 from subprocess import Popen, PIPE
-from thefuck.utils import for_app, eager, replace_command, replace_argument
+from thefuck.utils import (for_app, eager, replace_command, replace_argument,
+                           cache, which)
 
 regex = re.compile(r'error Command "(.*)" not found.')
 
 
 @for_app('yarn')
 def match(command):
-    return regex.findall(command.stderr)
+    return regex.findall(command.output)
 
 
 npm_commands = {'require': 'add'}
@@ -28,8 +29,12 @@ def _get_all_tasks():
             yield line.split(' ')[-1]
 
 
+if which('yarn'):
+    _get_all_tasks = cache(which('yarn'))(_get_all_tasks)
+
+
 def get_new_command(command):
-    misspelled_task = regex.findall(command.stderr)[0]
+    misspelled_task = regex.findall(command.output)[0]
     if misspelled_task in npm_commands:
         yarn_command = npm_commands[misspelled_task]
         return replace_argument(command.script, misspelled_task, yarn_command)
